Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mapsme/omim.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorvng <viktor.govako@gmail.com>2011-10-26 14:10:54 +0400
committerAlex Zolotarev <alex@maps.me>2015-09-23 01:26:53 +0300
commitb4d57fad501b83265e17a1a09a7994e802f0352e (patch)
tree68e856616276107c50071a8265a6e307ab11f07a /indexer/mwm_set.hpp
parent910e94c5377d3fb26751f35720af1f6a7563de56 (diff)
Don't make additional read of mwm header in app startup.
Diffstat (limited to 'indexer/mwm_set.hpp')
-rw-r--r--indexer/mwm_set.hpp11
1 files changed, 9 insertions, 2 deletions
diff --git a/indexer/mwm_set.hpp b/indexer/mwm_set.hpp
index bb0a81272e..ded539a3fa 100644
--- a/indexer/mwm_set.hpp
+++ b/indexer/mwm_set.hpp
@@ -56,8 +56,15 @@ public:
MwmValueBase * m_pValue;
};
- // Add new mwm. Returns false, if mwm with given fileName already exists.
- bool Add(string const & fileName);
+ /// Add new mwm. Returns false, if mwm with given fileName already exists.
+ /// @param[in] fileName File name (without full path) of country.
+ /// @param[out] r Limit rect of country.
+ bool Add(string const & fileName, m2::RectD & r);
+ inline bool Add(string const & fileName)
+ {
+ m2::RectD dummy;
+ return Add(fileName, dummy);
+ }
// Remove mwm.
void Remove(string const & fileName);